"use strict";
var path_1 = require('path');
var fs_1 = require('fs');
var electron_1 = require('electron');
var extend = require('deep-extend');
var windowStateKeeper = require('electron-window-state');
var BrowserConfig = (function () {
    function BrowserConfig() {
        this.loaded_config = null;
        this.window_state = null;
    }
    BrowserConfig.prototype.loadFrom = function (config_dir) {
        var _this = this;
        return new Promise(function (resolve) {
            try {
                var config_file = path_1.join(config_dir, 'browser-config.json');
                var content = fs_1.readFileSync(config_file, 'utf8');
                _this.loaded_config = JSON.parse(content);
            }
            catch (e) {
            }
            resolve();
        });
    };
    BrowserConfig.prototype.apply = function (opt) {
        if (typeof this.loaded_config !== 'object' || this.loaded_config === null) {
            return opt;
        }
        if (typeof this.loaded_config.window_options === 'object') {
            extend(opt, this.loaded_config.window_options);
        }
        if (this.loaded_config.remember_window_state) {
            var s = windowStateKeeper({
                defaultWidth: 1000,
                defaultHeight: 800,
                path: global.config_dir_path,
            });
            if (typeof s.x === 'number') {
                opt.x = s.x;
            }
            if (typeof s.y === 'number') {
                opt.y = s.y;
            }
            opt.width = s.width;
            opt.height = s.height;
            if (typeof s.isFullScreen === 'boolean') {
                opt.fullscreen = s.isFullScreen;
            }
            this.window_state = s;
        }
        return opt;
    };
    BrowserConfig.prototype.setupWindowState = function (win) {
        var _this = this;
        if (this.window_state === null) {
            return null;
        }
        win.once('closed', function () {
            _this.window_state.saveState(win);
        });
        if (this.window_state.isMaximized) {
            win.maximize();
        }
        return this.window_state;
    };
    BrowserConfig.prototype.configSingletonWindow = function (win) {
        if (this.loaded_config === null || !this.loaded_config.single_instance) {
            return false;
        }
        return electron_1.app.makeSingleInstance(function (argv, cwd) {
            if (win.isMinimized()) {
                win.restore();
            }
            win.focus();
            var args = argv.slice(2);
            if (args.length !== 0) {
                win.webContents.send('nyaovim:exec-commands', [
                    'cd ' + cwd,
                    'args ' + args.join(' '),
                ]);
            }
            return true;
        });
    };
    return BrowserConfig;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = BrowserConfig;
//# sourceMappingURL=browser-config.js.map